@@ -12,7 +12,8 @@ use std::{
     str::FromStr,
     string::FromUtf8Error,
 };
-pub use smartstring::MAX_INLINE;
+
+use crate::MAX_INLINE;
 
 #[cfg(feature = "diesel_types")]
 use diesel::{
